Module derive

Module derive 

Thin wrapper: PiSession → ConversationView → toolpath_convo::derive.

Converts Pi sessions into Toolpath Path and Graph documents by delegating to toolpath_convo::derive_path once the session has been mapped to a provider-agnostic toolpath_convo::ConversationView via crate::provider::session_to_view.

Functions

derive_graph
Derive a Toolpath Graph from multiple Pi sessions.
derive_path
Derive a Toolpath Path from a single Pi session.
derive_project
Derive a Graph from all sessions in a project.